@@ -2,10 +2,10 @@
 /*******************************************************************************
 
     Author ......... Jimmy Conner
-    Contact ........ jimmy@advcs.org
-    Home Site ...... http://www.advcs.org/
+    Contact ........ jimmy@sqmail.org
+    Home Site ...... http://www.sqmail.org/
     Program ........ Address Add
-    Version ........ 2.0
+    Version ........ 2.1
     Purpose ........ Allows you to add the From address to the address book
 
 *******************************************************************************/
@@ -22,6 +22,7 @@
 
    include_once(SM_PATH . 'functions/i18n.php');
    include_once(SM_PATH . 'functions/addressbook.php');
+   include_once(SM_PATH . 'plugins/address_add/includes/functions.php');
 
    // open address book, trash errors, skip LDAP
    $address = addressbook_init(false, true);
@@ -30,23 +31,25 @@
    $nick = '';
    if (isset($_GET['nick']))
       $nick = $_GET['nick'];
-   $nick = strip_tags(urldecode(urldecode($nick)));
+   $nick = clean(urldecode(urldecode($nick)));
    $name = '';
    if (isset($_GET['name']))
       $name = $_GET['name'];
-   $name = strip_tags(urldecode(urldecode($name)));
+   $name = clean(urldecode(urldecode($name)));
    $email = '';
    if (isset($_GET['email']))
       $email = $_GET['email'];
-   $email = strip_tags(urldecode(urldecode($email)));
+   $email = clean(urldecode(urldecode($email)));
    $first = '';
    if (isset($_GET['first']))
       $first = $_GET['first'];
-   $first = strip_tags(urldecode(urldecode($first)));
+
+   $first = clean(urldecode(urldecode($first)));
+
    $last = '';
    if (isset($_GET['last']))
       $last = $_GET['last'];
-   $last = strip_tags(urldecode(urldecode($last)));
+   $last = clean(urldecode(urldecode($last)));
 
    displayPageHeader($color, "None");
 
@@ -90,4 +93,5 @@
    print "</form></body>\n";
    print "</html>\n";
    textdomain('squirrelmail');
+
 ?>
\ No newline at end of file
