@@ -2,10 +2,10 @@
 /*******************************************************************************
 
     Author ......... Jimmy Conner
-    Contact ........ jimmy@advcs.org
-    Home Site ...... http://www.advcs.org/
+    Contact ........ jimmy@sqmail.org
+    Home Site ...... http://www.sqmail.org/
     Program ........ Address Add
-    Version ........ 2.0
+    Version ........ 2.1
     Purpose ........ Allows you to add the From address to the address book
 
 *******************************************************************************/
@@ -13,6 +13,8 @@
 global $address;
 include_once(SM_PATH . 'functions/addressbook.php');
 include_once(SM_PATH . 'functions/mime.php');
+include_once(SM_PATH . 'plugins/address_add/includes/functions.php');
+
 // open address book, trash errors, skip LDAP
 $address = addressbook_init(false, true);
 if ($address->localbackend == 0)
