@@ -2,10 +2,10 @@
 /*******************************************************************************
 
     Author ......... Jimmy Conner
-    Contact ........ jimmy@advcs.org
-    Home Site ...... http://www.advcs.org/
+    Contact ........ jimmy@sqmail.org
+    Home Site ...... http://www.sqmail.org/
     Program ........ Address Add
-    Version ........ 2.0
+    Version ........ 2.1
     Purpose ........ Allows you to add the From address to the address book
 
 *******************************************************************************/
@@ -23,4 +23,5 @@
          $this->decodedfrom = $message->header->from;
       }
       $this->decodedfrom = decodeHeader($this->decodedfrom);
+      $this->decodedfrom = clean($this->decodedfrom);
 ?>
\ No newline at end of file
