@@ -2,10 +2,10 @@
 /*******************************************************************************
 
     Author ......... Jimmy Conner
-    Contact ........ jimmy@advcs.org
-    Home Site ...... http://www.advcs.org/
+    Contact ........ jimmy@sqmail.org
+    Home Site ...... http://www.sqmail.org/
     Program ........ Address Add
-    Version ........ 2.0
+    Version ........ 2.1
     Purpose ........ Allows you to add the From address to the address book
 
 *******************************************************************************/
@@ -69,4 +69,10 @@
          $this->first = urlencode(urlencode($this->first));
       if ($this->last != "")
          $this->last = urlencode(urlencode($this->last));
+
+      $this->froms = clean($this->froms);
+      $this->nick = clean($this->nick);
+      $this->first = clean($this->first);
+      $this->last = clean($this->last);
+
 ?>
\ No newline at end of file
