@@ -2,10 +2,10 @@
 /*******************************************************************************
 
     Author ......... Jimmy Conner
-    Contact ........ jimmy@advcs.org
-    Home Site ...... http://www.advcs.org/
+    Contact ........ jimmy@sqmail.org
+    Home Site ...... http://www.sqmail.org/
     Program ........ Address Add
-    Version ........ 1.8
+    Version ........ 2.1
     Purpose ........ Allows you to add the From address to the address book
 
 *******************************************************************************/
