@@ -2,10 +2,10 @@
 /*******************************************************************************
 
     Author ......... Jimmy Conner
-    Contact ........ jimmy@advcs.org
-    Home Site ...... http://www.advcs.org/
+    Contact ........ jimmy@sqmail.org
+    Home Site ...... http://www.sqmail.org/
     Program ........ Address Add
-    Version ........ 2.0
+    Version ........ 2.1
     Purpose ........ Allows you to add the From address to the address book
 
 *******************************************************************************/
@@ -29,7 +29,7 @@ function address_add_start () {
 }
 
 function address_add_version() { 
-   return '2.0';
+   return '2.1';
 }
 
 ?>
\ No newline at end of file
